var map = L.map(document.getElementById('mapDIV'), {
    center: [-20.1438, -44.1301],
    zoom: 11
    });
	
	// Setup the mouse coordinate display
var coordDIV = document.createElement('div');
coordDIV.id = 'mapCoordDIV';
coordDIV.style.position = 'absolute';
coordDIV.style.bottom = '1px';
coordDIV.style.left = '150px';
coordDIV.style.zIndex = '900';
coordDIV.style.color = '#404040';
coordDIV.style.fontFamily = 'Georgia';
coordDIV.style.fontSize = '10pt';
coordDIV.style.backgroundColor = '#fff';


document.getElementById('mapDIV').appendChild(coordDIV);

// Setup the event to capture and display mouse movements
map.on('mousemove', function(e){
    var lat = e.latlng.lat.toFixed(3);
    var lon = e.latlng.lng.toFixed(3);
    document.getElementById('mapCoordDIV').innerHTML = 'Coordinates: ' + lat + ' , ' + lon;
      });

	
	
	// Base maps
	var basetopo = L.tileLayer('https://basemap.nationalmap.gov/arcgis/rest/services/USGSTopo/MapServer/WMTS/tile/1.0.0/USGSTopo/default/default028mm/{z}/{y}/{x}.png', {});
	var baserelief = L.tileLayer('https://tile.opentopomap.org/{z}/{x}/{y}.png', {});

	basetopo.addTo(map);
	baserelief.addTo(map);
 
    var thetrail = L.geoJSON(trail, {
        color: '#800000',
        weight: 3,
        dashArray: '12 8 12',
    });
    thetrail.bindTooltip('Trilha Brumadinho')
    thetrail.addTo(map);
	
	var towns = L.geoJSON(trail_stops, 
                      {pointToLayer: function(feature, latlng){
                          return L.circleMarker(latlng, {radius: 5, color: '#00008b',
                                                         fillOpacity: 0.5});
                      },
                      onEachFeature: function( feature, layer){
                          var name = feature.properties.name;
						  var elevation = feature.properties.elev_in_m;
                          var lat = feature.properties.prim_lat_d;
                          var lon = feature.properties.prim_lon_1;
                          

                          layer.bindPopup('<br/>Name: ' + name +
										 '<br/>Elevation: ' + elevation +
                                         '<br/>Lat/Lon: ' + lat + ' , ' + lon);
                          layer.on('mouseover', function() {layer.openPopup();});
                          layer.on('mouseout', function() {layer.closePopup();});
                      }
                     });

	towns.addTo(map);
	
	var placer = L.geoPackageFeatureLayer([], {
		  geoPackageUrl: 'code/points.gpkg',
		  layerName: 'points',
		  pointToLayer: function(feature, latlng){
			  return L.circleMarker(latlng, {radius: 5,
											stroke: false,
											fillColor: '#800000',
											fillOpacity: 0.6});
		  },
		  onEachFeature: function( feature, layer){
			  var name = feature.properties.name;			 
			  var lat = feature.properties.prim_lat_d;
			  var lon = feature.properties.prim_lon_1;

			  layer.bindPopup('Name: ' + name +							  
							  '<br/>Lat/Lon: ' + lat + ' , ' + lon);
			  layer.on('mouseover', function() {layer.openPopup();});
			  layer.on('mouseout', function() {layer.closePopup();});
		  }
	  });
  
	fromBox = document.getElementById('fromBox');
	toBox = document.getElementById('toBox');
	var featuremap = {};
	for (var i = 0; i < trail_stops['features'].length ; i++){
		feature = trail_stops['features'][i];
		//console.log(feature['properties']['name']);
		featuremap[feature['properties']['name']] = feature['properties'];
		var fromopt = document.createElement('option');
		fromopt.value = feature['properties']['name'];
		fromopt.innerHTML = feature['properties']['name'];
		fromBox.appendChild(fromopt);
		var toopt = document.createElement('option');
		toopt.value = feature['properties']['name'];
		toopt.innerHTML = feature['properties']['name'];
		toBox.appendChild(toopt);
	}

	document.getElementById('calculate').onclick = calculateDistance;

	function calculateDistance(){
		from = fromBox.value;
		to = toBox.value;
		fromobj = featuremap[from];
		toobj = featuremap[to];
		var fromPt = turf.point([fromobj['prim_lon_1'], fromobj['prim_lat_d']]);
		var toPt = turf.point([toobj['prim_lon_1'], toobj['prim_lat_d']]);
		var distance = turf.distance(fromPt, toPt, {units: 'kilometers'});
		console.log(distance)
		var distanceMiles = distance * 0.6214 

		document.getElementById('distanceResult').innerHTML = 'Distance is: ' + distance.toFixed(2) +
			' kilometers (' + distanceMiles.toFixed(2) + ' miles)';
	}

	
	var baselayers = {
    'Shaded Relief': baserelief,
    'National Map': basetopo
	};
	var overlays = {
		'The Trail': thetrail,
		'Towns': towns,
		'Points': placer
	};
	L.control.layers(baselayers, overlays).addTo(map);
	
	// Add scalebar

	var scale = L.control.scale()
	scale.addTo(map)

	// Add attribution
	map.attributionControl.addAttribution('National Map Topo');
	map.attributionControl.addAttribution('OpenTopoMap');